@@ -139,7 +139,7 @@ if __name__ == "__main__":
     mcp.run()
 '''
 
-TASKS_JSON_TEMPLATE = '''[
+TASKS_JSON_TEMPLATE = """[
   {{
     "prompt": "Increment the counter to reach 10",
     "mcp_config": {{
@@ -159,12 +159,12 @@ TASKS_JSON_TEMPLATE = '''[
     }}
   }}
 ]
-'''
+"""
 
 TEST_TASK_TEMPLATE = '''#!/usr/bin/env python
 """Simple example of running tasks from tasks.json.
 
-Make sure to run 'hud dev --build' in another terminal first!
+Make sure to run 'hud dev --build' in another terminal first, and install hud-python[agents]
 """
 
 import asyncio
@@ -208,14 +208,16 @@ async def main():
 
 if __name__ == "__main__":
     asyncio.run(main())
-'''
+'''  # noqa: E501
 
-NOTEBOOK_TEMPLATE = '''{{
+NOTEBOOK_TEMPLATE = """{{
  "cells": [
   {{
    "cell_type": "markdown",
    "metadata": {{}},
    "source": [
+    "Make sure to `pip install hud-python[agents]` before running this notebook\\n",
+    "\\n",
     "### Step 1: Create a Task\\n",
     "\\n",
     "A Task combines:\\n",
@@ -427,9 +429,18 @@ NOTEBOOK_TEMPLATE = '''{{
  "nbformat": 4,
  "nbformat_minor": 4
 }}
-'''
+"""  # noqa: E501
 
-README_TEMPLATE = '''# {title}
+ENV_FILE_TEMPLATE = """# HUD API Configuration
+# Get your API key from https://app.hud.so/account
+HUD_API_KEY=your_hud_api_key_here
+
+# Anthropic API Configuration (optional)
+# Required for using Claude agents - get from https://console.anthropic.com/
+ANTHROPIC_API_KEY=your_anthropic_api_key_here
+"""
+
+README_TEMPLATE = """# {title}
 
 A minimal HUD environment demonstrating the Task pattern with a simple counter.
 
@@ -437,21 +448,23 @@ A minimal HUD environment demonstrating the Task pattern with a simple counter.
 
 ### Interactive Development
 ```bash
-# 1. Start the environment (optional: with inspector)
+# 1. Configure your API keys (optional - only needed for evaluation)
+# Edit .env file to add your HUD_API_KEY and ANTHROPIC_API_KEY
+
+# 2. Start the environment (optional: with inspector)
 hud dev --build --inspector
 
-# 2. Choose your preferred way to test:
+# 3. Choose your preferred way to test:
 
-# Option A: Interactive notebook test_env.ipynb (great for learning!)
-
-# Option B: Simple Python script (runs all tasks from tasks.json)
-python test_task.py
-```
-
-### Run with an Agent
-```bash
-# Run the task with Claude
+# Option A: Run the task with Claude (requires ANTHROPIC_API_KEY)
 hud eval tasks.json --agent claude
+
+# Option B: Interactive notebook test_env.ipynb (great for learning!)
+# Requires installation:
+pip install hud-python[agents]
+
+# Option C: Simple Python script (runs all tasks from tasks.json)
+python test_task.py
 ```
 
 ## How HUD Environments Work
@@ -471,7 +484,7 @@ Once your environment is ready, you can share it with the community:
 
 ### 1. Push to Registry
 ```bash
-# Build and push your environment (this requires docker hub login and hud api key)
+# Build and push your environment (requires docker hub login and hud api key)
 hud build
 hud push
 ```
@@ -510,7 +523,7 @@ hud eval "your-org/your-dataset" --agent claude
 **Note**: Only public HuggingFace datasets appear as leaderboards!
 
 📚 Learn more: [Creating Benchmarks](https://docs.hud.so/evaluate-agents/create-benchmarks) | [Leaderboards](https://docs.hud.so/evaluate-agents/leaderboards)
-'''
+"""  # noqa: E501
 
 
 def sanitize_name(name: str) -> str:
@@ -613,6 +626,12 @@ def create_environment(name: str | None, directory: str, force: bool) -> None:
     notebook_path.write_text(notebook_content, encoding="utf-8")
     files_created.append("test_env.ipynb")
 
+    # .env file
+    env_file_path = target_dir / ".env"
+    env_file_content = ENV_FILE_TEMPLATE.strip() + "\n"
+    env_file_path.write_text(env_file_content, encoding="utf-8")
+    files_created.append(".env")
+
     # Success message
     design.header(f"Created HUD Environment: {name}")
 
